@@ -17,7 +17,8 @@ from minty.cqrs import CQRS
 from minty.infrastructure import InfrastructureFactory
 from minty_pyramid.renderer import jsonapi
 from pyramid.config import Configurator
-from uuid import uuid4
+from typing import Optional, Union
+from uuid import UUID, uuid4
 
 
 class Engine(GenericEngine):
@@ -26,8 +27,8 @@ class Engine(GenericEngine):
     def __init__(
         self,
         domains: list,
-        command_wrapper_middleware: list = None,
-        query_middleware: list = None,
+        command_wrapper_middleware: Optional[list] = None,
+        query_middleware: Optional[list] = None,
     ):
         if command_wrapper_middleware is None:
             command_wrapper_middleware = []
@@ -118,6 +119,7 @@ class Engine(GenericEngine):
         )
         config.add_view(view=exception_cqrs_catch_all, name="catch_all")
 
+        config.add_tween("minty_pyramid.generic_loader.RequestLoadGauge")
         config.add_tween("minty_pyramid.generic_loader.RequestTimer")
         config.add_tween("minty_pyramid.generic_loader.RequestDataLogger")
 
@@ -131,7 +133,7 @@ class Engine(GenericEngine):
         return config
 
 
-def _build_cqrs_setup(cqrs):
+def _build_cqrs_setup(cqrs: CQRS):
     """Create a callable for setting up the "CQRS" methods request objects.
 
     :param cqrs: A configured CQRS object
@@ -151,31 +153,33 @@ def _build_cqrs_setup(cqrs):
         """
 
         def get_query_instance(
-            request, domain: str, user_uuid: str, user_info=None
+            request, domain: str, user_uuid: Union[UUID, str], user_info=None
         ):
+            validated_user_uuid = UUID(str(user_uuid))
+
             cqrs_instance = cqrs.get_query_instance(
                 correlation_id=request.request_id,
                 domain=domain,
                 context=request.host,
-                user_uuid=user_uuid,
+                user_uuid=validated_user_uuid,
+                user_info=user_info,
             )
-            # TODO pass user_info in parameters instead setting like so
-            cqrs_instance.query_instance.user_info = user_info
             return cqrs_instance
 
         config.add_request_method(get_query_instance, "get_query_instance")
 
         def get_command_instance(
-            request, domain: str, user_uuid: str, user_info=None
+            request, domain: str, user_uuid: Union[UUID, str], user_info=None
         ):
+            validated_user_uuid = UUID(str(user_uuid))
+
             cqrs_instance = cqrs.get_command_instance(
                 correlation_id=request.request_id,
                 domain=domain,
                 context=request.host,
-                user_uuid=user_uuid,
+                user_uuid=validated_user_uuid,
+                user_info=user_info,
             )
-            # TODO pass user_info in parameters instead setting like so
-            cqrs_instance.command_instance.user_info = user_info
             return cqrs_instance
 
         config.add_request_method(get_command_instance, "get_command_instance")
