@@ -3,11 +3,14 @@
 # SPDX-License-Identifier: EUPL-1.2
 
 import datetime
+import logging
 from minty.entity import Entity, EntityCollection, ValueObject
 from pyramid.renderers import JSON
 from typing import Any, Dict
 from uuid import UUID
 
+logger = logging.getLogger(__name__)
+
 
 class jsonapi(JSON):
     jsonapi_adapters = {
@@ -60,6 +63,8 @@ class jsonapi(JSON):
         return [entity for entity in obj]
 
     def __links_for_entity(self, entity):
+        if not hasattr(self.view, "create_link_from_entity"):
+            logger.warning(f"Unknown kind of view: {self.view.__module__}")
         self_link = self.view.create_link_from_entity(entity)
         if self_link:
             return {"links": {"self": self_link}}
@@ -155,7 +160,7 @@ class jsonapi(JSON):
             del object_attributes[relationshipkey]
         return object_relationships
 
-    def _entity_adapter(self, obj, request):
+    def _entity_adapter(self, obj: Entity, request):
         """Transforms an entity in a JSON:API styled format
 
         See renderers documentation of Pyramid for more information about
@@ -184,6 +189,7 @@ class jsonapi(JSON):
         meta = self._build_meta(obj)
         if meta:
             result["meta"] = meta
+
         return result
 
     def _build_meta(self, obj: Entity) -> dict:
@@ -207,10 +213,12 @@ class jsonapi(JSON):
         """Transforms a datetime object in a JSONApi styled format"""
         return obj.isoformat()
 
-    def _value_object_adapter(self, obj, request):
+    def _value_object_adapter(self, obj: ValueObject, request):
         """Transforms a ValueObject in a JSONApi styled format
 
         See renderers documentation of Pyramid for more information about
         using adapters
         """
-        return obj.dict()
+        logger = logging.getLogger(__name__)
+        logger.info(f"XXX {obj}")
+        return obj.dict(by_alias=True)
