@@ -5,13 +5,15 @@
 import logging
 import re
 from minty.cqrs import UserInfo
+from minty.entity import RedirectResponse
 from minty.validation import assert_never
 from minty_pyramid.session_manager import (
     check_user_permission,
     get_logged_in_user,
 )
 from pyramid.httpexceptions import HTTPBadRequest, HTTPForbidden
-from typing import Dict, Literal, Optional, Set, TypedDict
+from pyramid.response import Response
+from typing import Dict, Literal, Optional, Set, TypedDict, Union
 from uuid import UUID
 
 log = logging.getLogger(__name__)
@@ -249,9 +251,24 @@ class JSONAPIEntityView:
         else:
             return {"data": None}
 
+    def transform_response_from_query(self, response) -> Union[dict, Response]:
+        """Transform response from query"""
+        if response is None:
+            return {"data": None}
+        elif isinstance(response, RedirectResponse):
+            return Response(status_int=302, location=response.location)
+        else:
+            json_response = {
+                "data": response,
+                "links": {"self": self.request.current_route_path()},
+            }
+            self._apply_included_entities(response, json_response)
+            self._apply_meta(response, json_response)
+            return json_response
+
     def transform_response_from_command_or_query(
         self, response, calldata: ViewMapping, params
-    ) -> dict:
+    ) -> Optional[Union[dict, Response]]:
         """
         Transforms a response from a command to a proper JSONApi structure
 
@@ -277,15 +294,7 @@ class JSONAPIEntityView:
         if calldata["cq"] == "command":
             return self.transform_response_from_command(calldata, params)
         elif calldata["cq"] == "query":
-            if response is None:
-                return {"data": None}
-            else:
-                json_response = {
-                    "data": response,
-                    "links": {"self": self.request.current_route_path()},
-                }
-                self._apply_meta(response, json_response)
-                return json_response
+            return self.transform_response_from_query(response)
 
         assert_never(calldata["cq"])  # pragma: no cover
 
@@ -298,6 +307,13 @@ class JSONAPIEntityView:
         ):
             json_response["meta"] = {"total_results": response.total_results}
 
+    def _apply_included_entities(self, response, json_response: dict):
+        if (
+            hasattr(response, "included_entities")
+            and response.included_entities is not None
+        ):
+            json_response["included"] = response.included_entities
+
     def _collect_params_as_array(self, k, v, params):
         for pk, pv in self.request.params.items():
             match = re.search(r"^" + k + r"\[([^\]]+)\]$", pk)
